Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2013-10-26 05:06:19 +0400
committerCampbell Barton <ideasman42@gmail.com>2013-10-26 05:06:19 +0400
commit48c1e0c0fcb66502026721a50ae5e17470aee816 (patch)
tree94e812e78479df2d84dc8d0faccad212ca6fde56 /intern/cycles/util/util_task.h
parent00160d4a1be401b789bc470cc397b1172353b116 (diff)
spelling: use American spelling for canceled
Diffstat (limited to 'intern/cycles/util/util_task.h')
-rw-r--r--intern/cycles/util/util_task.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/intern/cycles/util/util_task.h b/intern/cycles/util/util_task.h
index 22515e3e433..42a1e2f5a58 100644
--- a/intern/cycles/util/util_task.h
+++ b/intern/cycles/util/util_task.h
@@ -66,7 +66,7 @@ public:
void cancel(); /* cancel all tasks, keep worker threads running */
void stop(); /* stop all worker threads */
- bool cancelled(); /* for worker threads, test if cancelled */
+ bool canceled(); /* for worker threads, test if canceled */
protected:
friend class TaskScheduler;
@@ -142,7 +142,7 @@ public:
void cancel(); /* cancel all tasks, keep worker thread running */
void stop(); /* stop worker thread */
- bool cancelled(); /* for worker thread, test if cancelled */
+ bool canceled(); /* for worker thread, test if canceled */
protected:
void num_decrease(int done);